CustomException class

CustomException is a base class for exceptions in the platform file editors. Attributes:

  • message: The error message associated with the exception.
Implemented types
Implementers

Constructors

CustomException(String message)

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited