RenameOption enum

RenameOption is an enum representing different renaming options.

Inheritance
Available extensions

Values

targets → const RenameOption
value → const RenameOption

Properties

abbr → String

Available on RenameOption, provided by the RenameOptionExtension extension

Returns the abbreviation of the rename option.
no setter
hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
name → String

Available on RenameOption, provided by the RenameOptionExtension extension

Returns the name of the rename option.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<RenameOption>
A constant List of the values in this enum, in order of their declaration.