utils/files library

Functions

convertPath(List<String> paths) → String
Converts a list of path segments into a platform-specific file path. Parameters:
readFileAsLineByline({required String filePath, required RenamePlatform platform}) → Future<List<String?>>
Reads a file line by line. Parameters:
writeFile({required String filePath, required String content, required RenamePlatform platform}) → Future<File>
Writes the provided content to a file at the specified filePath. Parameters: